@@ -21,7 +21,7 @@ __author__ = "Djordje Bajic, Jean Vila, Jeremy Chacon"
 __copyright__ = "Copyright 2019, The COMETS Consortium"
 __credits__ = ["Djordje Bajic", "Jean Vila", "Jeremy Chacon"]
 __license__ = "MIT"
-__version__ = "0.3.8"
+__version__ = "0.4.5"
 __comets_compatibility__ = "2.10.2" # version of comets this was tested with
 
 __maintainer__ = "Djordje Bajic"
@@ -119,7 +119,6 @@ class comets:
     def __init__(self, layout,
                  parameters, relative_dir : str =''):
 
-
         # define instance variables
         self.working_dir = os.getcwd() + '/' + relative_dir
         try:
@@ -154,11 +153,15 @@ class comets:
         self.parameters = parameters
 
         # dealing with output files
-        params.set_param("useLogNameTimeStamp", False)
-        params.set_param("TotalBiomassLogName", self.parameters.all_params['TotalBiomassLogName'] + hex(id(self)))
-        params.set_param("BiomassLogName", self.parameters.all_params['BiomassLogName'] + hex(id(self)))
-        params.set_param("FluxLogName", self.parameters.all_params['MediaBiomassLogName'] + hex(id(self)))
-        params.set_param("MediaBiomassLogName", self.parameters.all_params['MediaBiomassLogName'] + hex(id(self)))
+        self.parameters.set_param("useLogNameTimeStamp", False)
+        self.parameters.set_param("TotalBiomassLogName",
+                                  self.parameters.all_params['TotalBiomassLogName'] + '_' + hex(id(self)))
+        self.parameters.set_param("BiomassLogName",
+                                  self.parameters.all_params['BiomassLogName'] + '_' + hex(id(self)))
+        self.parameters.set_param("FluxLogName",
+                                  self.parameters.all_params['FluxLogName'] + '_' + hex(id(self)))
+        self.parameters.set_param("MediaLogName",
+                                  self.parameters.all_params['MediaLogName'] + '_' + hex(id(self)))
 
     def __build_default_classpath_pieces(self):
         """
@@ -351,11 +354,10 @@ class comets:
 
         to_append = '_' + hex(id(self))
         # write the files for comets in working_dir
-        c_global = self.working_dir + '.current_global' + to_append)
-        c_package = self.working_dir + '.current_package' + to_append)
-        c_script = self.working_dir + '.current_script' + to_append)
+        c_global = self.working_dir + '.current_global' + to_append
+        c_package = self.working_dir + '.current_package' + to_append
+        c_script = self.working_dir + '.current_script' + to_append
  
-
         self.layout.write_necessary_files(self.working_dir, to_append)
 
         # self.layout.write_layout(self.working_dir + '.current_layout')
@@ -364,22 +366,23 @@ class comets:
         if os.path.isfile(c_script):
             os.remove(c_script)
         with open(c_script, 'a') as f:
-            f.write('load_comets_parameters ' + '.current_global_' + hex(id(self))) + '\n')
-            f.writelines('load_package_parameters ' + '.current_package_' + hex(id(self))) + '\n')
-            f.writelines('load_layout ' + '.current_layout_' + hex(id(self))))
+            f.write('load_comets_parameters ' + '.current_global' + to_append + '\n')
+            f.writelines('load_package_parameters ' + '.current_package' + to_append + '\n')
+            f.writelines('load_layout ' + '.current_layout' + to_append)
 
         if platform.system() == 'Windows':
             self.cmd = ('\"' + self.COMETS_HOME +
-                     '\\comets_scr' + '\" \"' +
-                    c_script +
-                    '\"')
+                        '\\comets_scr' + '\" \"' +
+                        c_script +
+                        '\"')
         else:
-        # simulate
+            # simulate
             self.cmd = ('java -classpath ' + self.JAVA_CLASSPATH +
-                    # ' -Djava.library.path=' + self.D_JAVA_LIB_PATH +
-                    ' edu.bu.segrelab.comets.Comets -loader' +
-                    ' edu.bu.segrelab.comets.fba.FBACometsLoader' +
-                    ' -script "' + '.current_script' + '"')
+                        # ' -Djava.library.path=' + self.D_JAVA_LIB_PATH +
+                        ' edu.bu.segrelab.comets.Comets -loader' +
+                        ' edu.bu.segrelab.comets.fba.FBACometsLoader' +
+                        ' -script "' + c_script + '"')
+
         p = sp.Popen(self.cmd, 
                      cwd = self.working_dir,
                      shell=True, stdout=sp.PIPE, stderr=sp.STDOUT)
@@ -433,21 +436,20 @@ class comets:
 
         # Read spatial biomass log
         if self.parameters.all_params['writeBiomassLog']:
-            biomass_out_file = self.working_dir + 'biomass_log_' + hex(id(self))
-            self.biomass = pd.read_csv(biomass_out_file,
-                                       header=None, delimiter=r'\s+',
-                                       names=['cycle', 'x', 'y',
-                                              'species', 'biomass'])
+            self.biomass = pd.read_csv(self.working_dir + self.parameters.all_params[
+                'BiomassLogName'], header=None, delimiter=r'\s+', names=['cycle', 'x', 'y',
+                                                                         'species', 'biomass'])
             # cut off extension added by toolbox
             self.biomass['species'] = [sp[:-4] if '.cmd' in sp else sp for sp in self.biomass.species]
 
             if delete_files:
-                os.remove(biomass_out_file)
+                os.remove(self.working_dir + self.parameters.all_params['BiomassLogName'])
 
         # Read evolution-related logs
         if 'evolution' in list(self.parameters.all_params.keys()):
             if self.parameters.all_params['evolution']:
-                genotypes_out_file = self.working_dir + 'GENOTYPES_biomass_log_' + hex(id(self))
+                genotypes_out_file = self.working_dir + 'GENOTYPES_' + self.parameters.all_params[
+                    'BiomassLogName']
                 self.genotypes = pd.read_csv(genotypes_out_file,
                                              header=None, delimiter=r'\s+',
                                              names=['Ancestor',
@@ -469,7 +471,7 @@ class comets:
             os.remove(c_global)
             os.remove(c_package)
             os.remove(c_script)
-            os.remove(self.working_dir + '.current_layout')
+            os.remove(self.working_dir + '.current_layout' + to_append)
             os.remove(self.working_dir + 'COMETS_manifest.txt')  # todo: stop writing this in java
         print('Done!')
 
