@@ -592,9 +592,9 @@ class model:
             
         """
         self.id = os.path.splitext(os.path.basename(path))[0]
-
+        
         # in this way, its robust to empty lines:
-        m_f_lines = [s for s in __read_file(path).splitlines() if s]
+        m_f_lines = [s for s in _read_file(path).splitlines() if s]
         m_filedata_string = os.linesep.join(m_f_lines)
         ends = []
         for k in range(0, len(m_f_lines)):
@@ -828,7 +828,7 @@ class model:
         path_to_delete = path_to_delete + self.id + to_append + '.cmd'
         os.remove(path_to_delete)
         
-    def write_comets_model(self, working_dir : str =None, to_append : str=""):
+    def write_comets_model(self, working_dir : str = None):
         """ writes the COMETS model object to a file 
             
             This writes the current model object in COMETS format to file, either
@@ -846,7 +846,7 @@ class model:
         path_to_write = ""
         if working_dir is not None:
             path_to_write = working_dir
-        path_to_write = path_to_write + self.id + to_append + '.cmd'
+        path_to_write = path_to_write + self.id + '.cmd'
 
         # format variables for writing comets model
         bnd = self.reactions.loc[(self.reactions['LB']
@@ -1000,7 +1000,7 @@ class model:
             f.write(r'//' + '\n')
 
 
-def __read_file(filename: str) -> str:
+def _read_file(filename: str) -> str:
     """ helper function to read non-rectangular files.
     """
     f = open(filename, 'r')
